@@ -115,13 +115,14 @@ impl Safe {
     ///
     /// ## Example
     ///
-    /// ```rust
+    /// ```rust,no_run
     /// # use rand::distributions::Alphanumeric;
     /// # use rand::{thread_rng, Rng};
     /// # use sn_api::Safe;
     /// # let mut safe = Safe::default();
-    /// # async_std::task::block_on(async {
-    /// #   safe.connect("", Some("fake-credentials")).await.unwrap();
+    /// # let rt = tokio::runtime::Runtime::new().unwrap();
+    /// # rt.block_on(async {
+    /// #   safe.connect(None, None, None).await.unwrap();
     ///     let rand_string: String = thread_rng().sample_iter(&Alphanumeric).take(15).collect();
     ///     let file_xorurl = safe.files_store_public_blob(&vec![], None, false).await.unwrap();
     ///     let (xorurl, _processed_entries, nrs_map_container) = safe.nrs_map_container_create(&rand_string, &file_xorurl, true, false, false).await.unwrap();
@@ -145,7 +146,7 @@ impl Safe {
             ))
         } else {
             let mut nrs_map = NrsMap::default();
-            let link = nrs_map.update(&name, link, default, hard_link)?;
+            let link = nrs_map.update(name, link, default, hard_link)?;
             let mut processed_entries = ProcessedEntries::new();
             processed_entries.insert(name.to_string(), (CONTENT_ADDED_SIGN.to_string(), link));
 
@@ -225,13 +226,14 @@ impl Safe {
     ///
     /// ## Example
     ///
-    /// ```rust
+    /// ```rust,no_run
     /// # use sn_api::Safe;
     /// # use rand::distributions::Alphanumeric;
     /// # use rand::{thread_rng, Rng};
     /// # let mut safe = Safe::default();
-    /// # async_std::task::block_on(async {
-    /// #   safe.connect("", Some("fake-credentials")).await.unwrap();
+    /// # let rt = tokio::runtime::Runtime::new().unwrap();
+    /// # rt.block_on(async {
+    /// #   safe.connect(None, None, None).await.unwrap();
     ///     let rand_string: String = thread_rng().sample_iter(&Alphanumeric).take(15).collect();
     ///     let file_xorurl = safe.files_store_public_blob(&vec![], Some("text/plain"), false).await.unwrap();
     ///     let (xorurl, _processed_entries, _nrs_map) = safe.nrs_map_container_create(&rand_string, &file_xorurl, true, false, false).await.unwrap();
@@ -289,13 +291,13 @@ impl Safe {
 
                 debug!("Nrs map v{} retrieved: {:?} ", version, &serialised_nrs_map);
                 let nrs_map =
-                    serde_json::from_str(&String::from_utf8_lossy(&serialised_nrs_map.as_slice()))
+                    serde_json::from_str(&String::from_utf8_lossy(serialised_nrs_map.as_slice()))
                         .map_err(|err| {
-                            Error::ContentError(format!(
-                                "Couldn't deserialise the NrsMap stored in the NrsContainer: {:?}",
-                                err
-                            ))
-                        })?;
+                        Error::ContentError(format!(
+                            "Couldn't deserialise the NrsMap stored in the NrsContainer: {:?}",
+                            err
+                        ))
+                    })?;
 
                 Ok((version, nrs_map))
             }
@@ -633,7 +635,7 @@ mod tests {
     #[tokio::test]
     async fn test_nrs_validate_name_with_slash() -> Result<()> {
         let nrs_name = "name/with/slash";
-        match validate_nrs_name(&nrs_name) {
+        match validate_nrs_name(nrs_name) {
             Ok(_) => Err(anyhow!(
                 "Unexpectedly validated nrs name with slashes {}",
                 nrs_name
