@@ -75,25 +75,25 @@ fn read_default_peers_from_file() -> Result<HashSet<SocketAddr>> {
         ),
         Some(mut paths) => {
             paths.push(DEFAULT_PEER_FILE_IN_HOME);
-            paths.display().to_string()
+            paths
         }
     };
 
     let raw_json = fs::read_to_string(&default_peer_file).with_context(|| {
         format!(
-            "Failed to read bootstraping contacts list from file: {}",
+            "Failed to read bootstraping contacts list from file: {:?}",
             &default_peer_file
         )
     })?;
-    let urls: Vec<String> = serde_json::from_str(&raw_json).with_context(|| {
+
+    let sockaddrs: HashSet<SocketAddr> = serde_json::from_str(&raw_json).with_context(|| {
         format!(
-            "Failed to parse bootstraping contacts list from file: {}",
+            "Failed to parse bootstraping contacts list from file: {:?}",
             &default_peer_file
         )
     })?;
-    let sockaddrs: Result<HashSet<SocketAddr>, std::net::AddrParseError> =
-        urls.iter().map(|u| u.parse()).collect();
-    Ok(sockaddrs?)
+
+    Ok(sockaddrs)
 }
 
 fn get_bootstrap_contacts() -> Result<HashSet<SocketAddr>> {
@@ -115,14 +115,23 @@ fn get_bootstrap_contacts() -> Result<HashSet<SocketAddr>> {
 
 #[macro_export]
 macro_rules! retry_loop {
-    ($async_func:expr) => {
+    ($n:literal, $async_func:expr) => {{
+        let mut retries = $n;
         loop {
             match $async_func.await {
                 Ok(val) => break val,
-                Err(_) => tokio::time::sleep(std::time::Duration::from_millis(200)).await,
+                Err(_) if retries > 0 => {
+                    retries -= 1;
+                    tokio::time::sleep(std::time::Duration::from_millis(1000)).await;
+                }
+                Err(e) => anyhow::bail!("Failed after {} retries: {:?}", $n, e),
             }
         }
-    };
+    }};
+    // Defaults to 10 retries if n is not provided
+    ($async_func:expr) => {{
+        retry_loop!(10, $async_func)
+    }};
 }
 
 #[macro_export]
